| Title: | a global dataset of leaf D13C data |
|---|---|
| Description: | These are data from bulk leaf D13C data collected on many different species from across the world. |
| Authors: | Will Cornwell |
| Maintainer: | Will Cornwell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.2 |
| Built: | 2026-05-21 09:42:36 UTC |
| Source: | https://github.com/traitecoevo/leaf13C |
Retrieve a versioned copy of the leaf13C dataset
get_data(version = NULL, path = NULL) dataset_versions(local = FALSE, path = NULL) dataset_version_current(local = FALSE, path = NULL) dataset_del(version, path = NULL)get_data(version = NULL, path = NULL) dataset_versions(local = FALSE, path = NULL) dataset_version_current(local = FALSE, path = NULL) dataset_del(version, path = NULL)
version |
Optional character string specifying the dataset version to retrieve.
If |
path |
Optional file path to store and access the dataset locally.
If |
local |
Logical indicating if local or github versions should
be polled. With any luck, |
This function provides access to a versioned dataset hosted on GitHub using the datastorr framework. It will download and cache the dataset if not already available locally, and return it as a data frame.
If no version is specified, the most recent available version will be used.
If no path is specified, a suitable persistent directory will be chosen
automatically using rappdirs::user_data_dir().
A data frame containing the leaf13C dataset.
# Load the most recent version of the dataset data <- get_data() # Load a specific version of the dataset data <- get_data(version = "0.1.0") # Use a custom path data <- get_data(path = "~/my_data")# Load the most recent version of the dataset data <- get_data() # Load a specific version of the dataset data <- get_data(version = "0.1.0") # Use a custom path data <- get_data(path = "~/my_data")